# -*- coding: utf-8 -*-

from __future__ import absolute_import

from django.conf import settings

CMS_VIMEO_LOOP = getattr(settings, "CMS_VIMEO_LOOP", False)
CMS_VIMEO_AUTOPLAY = getattr(settings, "CMS_VIMEO_AUTOPLAY", False)

CMS_VIMEO_BG_COLOR = getattr(settings, "CMS_VIMEO_BG_COLOR", "000000")
CMS_VIMEO_TEXT_COLOR = getattr(settings, "CMS_VIMEO_TEXT_COLOR", "FFFFFF")
CMS_VIMEO_SEEKBAR_COLOR = getattr(
    settings, "CMS_VIMEO_SEEKBAR_COLOR", "13ABEC")

CMS_VIMEO_SEEKBARBG_COLOR = getattr(
    settings, "CMS_VIMEO_SEEKBARBG_COLOR", "333333")

CMS_VIMEO_LOADINGBAR_COLOR = getattr(
    settings, "CMS_VIMEO_LOADINGBAR_COLOR", "828282")

CMS_VIMEO_BUTTON_OUT_COLOR = getattr(
    settings, "CMS_VIMEO_BUTTON_OUT_COLOR", "333333")

CMS_VIMEO_BUTTON_OVER_COLOR = getattr(
    settings, "CMS_VIMEO_BUTTON_OVER_COLOR", "000000")

CMS_VIMEO_BUTTON_HIGHLIGHT_COLOR = getattr(
    settings, "CMS_VIMEO_BUTTON_HIGHLIGHT_COLOR", "FFFFFF")

CMS_VIMEO_PLUGIN_ENABLE_ADVANCED_SETTINGS = getattr(
    settings, "CMS_VIMEO_PLUGIN_ENABLE_ADVANCED_SETTINGS", True)



# -*- coding: utf-8 -*-

from __future__ import absolute_import

from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import settings
from .forms import VimeoVideoForm
from .models import VimeoVideo


class VimeoVideoPlugin(CMSPluginBase):
    model = VimeoVideo
    name = _("Vimeo Video")
    form = VimeoVideoForm

    render_template = "djangocms_vimeo/video.html"

    general_fields = [
        'movie_url',
        ('width', 'height'),
        'auto_play',
        'loop',
    ]

    fieldsets = [
        (None, {
            'fields': general_fields,
        }),
    ]

    def render(self, context, instance, placeholder):
        context.update({
            'object': instance,
            'placeholder': placeholder,
        })
        return context

plugin_pool.register_plugin(VimeoVideoPlugin)



# -*- coding: utf-8 -*-

from __future__ import absolute_import

from cms.test_utils.testcases import CMSTestCase
from django.test import TestCase


class VimeoTestCase(CMSTestCase):

    def setUp(self):
        pass



# -*- coding: utf-8 -*-

from __future__ import absolute_import
import os

from django.db import models
from django.utils.translation import ugettext_lazy as _

from cms.utils.compat.dj import python_2_unicode_compatible
from cms.models import CMSPlugin

from . import settings


@python_2_unicode_compatible
class VimeoVideo(CMSPlugin):
    """
    Vimeo video player (size, video url) and
    plugin (background color) settings.
    """

    # player settings
    movie_url = models.CharField(
        _('movie url'), max_length=255,
        help_text=_('Vimeo video url. '
                    'Example: https://vimeo.com/50516814'),
        blank=True, null=True)

    width = models.PositiveSmallIntegerField(_('width'))

    height = models.PositiveSmallIntegerField(_('height'))

    auto_play = models.BooleanField(
        _('auto play'), default=settings.CMS_VIMEO_AUTOPLAY)

    loop = models.BooleanField(_('loop'), default=settings.CMS_VIMEO_LOOP)

    def __str__(self):
        name = self.movie_url
        return u"%s" % os.path.basename(name)

    def get_height(self):
        """
        Return the height of the movie in pixels.
        """

        return "%s" % self.height

    def get_width(self):
        """
        Return the width of the movie in pixels.
        """
        return "%s" % self.width

    def get_movie(self):
        """
        Return the url of this movie.
        """

        return self.movie_url



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='VimeoVideo',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('movie_url', models.CharField(help_text='Vimeo video url. Example: https://vimeo.com/50516814', max_length=255, null=True, verbose_name='movie url', blank=True)),
                ('width', models.PositiveSmallIntegerField(verbose_name='width')),
                ('height', models.PositiveSmallIntegerField(verbose_name='height')),
                ('auto_play', models.BooleanField(default=False, verbose_name='auto play')),
                ('loop', models.BooleanField(default=False, verbose_name='loop')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import absolute_import

from django import forms

from .models import VimeoVideo


class VimeoVideoForm(forms.ModelForm):
    class Meta:
        model = VimeoVideo
        exclude = ('page', 'position', 'placeholder', 'language',
                   'plugin_type')
